@@ -1,9 +1,7 @@
 /*
-    $Id: flvmeta.c 231 2011-06-27 13:46:19Z marc.noirot $
+    FLVMeta - FLV Metadata Editor
 
-    FLV Metadata updater
-
-    Copyright (C) 2007-2011 Marc Noirot <marc.noirot AT gmail.com>
+    Copyright (C) 2007-2013 Marc Noirot <marc.noirot AT gmail.com>
 
     This file is part of FLVMeta.
 
@@ -117,7 +115,7 @@ static void help(const char * name) {
            "  -r, --raw                 equivalent to --dump-format=raw\n"
            "  -x, --xml                 equivalent to --dump-format=xml\n"
            "  -y, --yaml                equivalent to --dump-format=yaml\n"
-           "  -e, --event               specify the event to be dumped instead of 'onMetadata'\n"
+           "  -e, --event=EVENT         specify the event to be dumped instead of 'onMetadata'\n"
            "\nCheck options:\n"
            "  -l, --level=LEVEL         print only messages where level is at least LEVEL\n"
            "                            LEVEL is 'info', 'warning' (default), 'error', or 'fatal'\n"
@@ -397,7 +395,6 @@ int main(int argc, char ** argv) {
             case ERROR_OPEN_WRITE: fprintf(stderr, "%s: cannot open %s for writing\n", argv[0], options.output_file); break;
             case ERROR_INVALID_TAG: fprintf(stderr, "%s: invalid FLV tag\n", argv[0]); break;
             case ERROR_WRITE: fprintf(stderr, "%s: unable to write to %s\n", argv[0], options.output_file); break;
-            case ERROR_SAME_FILE: fprintf(stderr, "%s: input file and output file must be different\n", argv[0]); break;
         }
     }
 
